@@ -1,6 +1,11 @@
 // Density function for the Ratcliff Diffusion Decision Model (DDM)
 
-#include "funcs.h"
+#include "parameter_checks.h"
+#include "dfddm_helper_functions/func_defs.h"
+#include "dfddm_helper_functions/helper_funcs.h"
+#include "dfddm_helper_functions/density_funcs.h"
+#include "dfddm_helper_functions/sum_funcs.h"
+#include "dfddm_helper_functions/num_funcs.h"
 
 
 
